@@ -14,7 +14,7 @@ from google.cloud import pubsub_v1
 from .auth import AbstractAuth
 from .device_manager import DeviceManager
 from .event import AsyncEventCallback, EventMessage
-from .exceptions import AuthException, SubscriberException
+from .exceptions import AuthException, ConfigurationException, SubscriberException
 from .google_nest_api import GoogleNestAPI
 
 _LOGGER = logging.getLogger(__name__)
@@ -42,7 +42,7 @@ class DefaultSubscriberFactory(AbstractSusbcriberFactory):
     async def async_new_subscriber(
         self, creds, subscription_name, loop, async_callback
     ) -> pubsub_v1.subscriber.futures.StreamingPullFuture:
-        """Creates a new subscriber with a blocking to async bridge."""
+        """Create a new subscriber with a blocking to async bridge."""
 
         def callback_wrapper(message: pubsub_v1.subscriber.message.Message):
             future = asyncio.run_coroutine_threadsafe(async_callback(message), loop)
@@ -58,12 +58,12 @@ class DefaultSubscriberFactory(AbstractSusbcriberFactory):
             )
 
     def _new_subscriber(self, creds, subscription_name, callback_wrapper):
-        """Issues a command to verify subscriber creds are correct."""
+        """Issue a command to verify subscriber creds are correct."""
         subscriber = pubsub_v1.SubscriberClient(credentials=creds)
         subscription = subscriber.get_subscription(subscription=subscription_name)
         if subscription.topic:
             if not EXPECTED_TOPIC_REGEXP.match(subscription.topic):
-                raise SubscriberException(
+                raise ConfigurationException(
                     "Subscription misconfigured. Expected topic name to "
                     f"match '{EXPECTED_TOPIC_REGEXP.pattern}' but was "
                     f"'{subscription.topic}'."
@@ -78,7 +78,7 @@ class DefaultSubscriberFactory(AbstractSusbcriberFactory):
 
 
 class GoogleNestSubscriber:
-    """Subscribes to events from the Google Nest feed."""
+    """Subscribe to events from the Google Nest feed."""
 
     def __init__(
         self,
@@ -89,17 +89,15 @@ class GoogleNestSubscriber:
         loop: Optional[asyncio.AbstractEventLoop] = None,
         watchdog_delay: float = 10,
     ):
-        """Initialize the subscriber for the specified topic"""
+        """Initialize the subscriber for the specified topic."""
         self._auth = auth
         self._subscriber_id = subscriber_id
         self._api = GoogleNestAPI(auth, project_id)
         self._loop = loop or asyncio.get_event_loop()
+        self._device_manager_task = None
         self._subscriber_factory = subscriber_factory
         self._subscriber_future = None
         self._callback = None
-        self._device_manager_task = asyncio.create_task(
-            self._async_create_device_manager()
-        )
         self._healthy = True
         self._watchdog_delay = watchdog_delay
         if self._watchdog_delay > 0:
@@ -112,9 +110,9 @@ class GoogleNestSubscriber:
         self._callback = callback
 
     async def start_async(self):
-        """Starts the subscriber."""
+        """Start the subscriber."""
         if not EXPECTED_SUBSCRIBER_REGEXP.match(self._subscriber_id):
-            raise SubscriberException(
+            raise ConfigurationException(
                 "Subscription misconfigured. Expected subscriber_id to "
                 f"match '{EXPECTED_SUBSCRIBER_REGEXP.pattern}' but was "
                 f"'{self._subscriber_id}'"
@@ -135,14 +133,14 @@ class GoogleNestSubscriber:
                 f"Failed to create subscriber '{self._subscriber_id}' id was not found"
             ) from err
         except Unauthenticated as err:
-            raise AuthException("Failed to authenticate subscriber") from err
+            raise AuthException("Failed to authenticate subscriber: {err}") from err
         except GoogleAPIError as err:
             raise SubscriberException(
-                f"Failed to create subscriber '{self._subscriber_id}'"
+                f"Failed to create subscriber '{self._subscriber_id}': {err}"
             ) from err
 
         if not self._healthy:
-            _LOGGER.info("Subscriber reconnected")
+            _LOGGER.debug("Subscriber reconnected")
             self._healthy = True
         if self._subscriber_future:
             self._subscriber_future.add_done_callback(self._done_callback)
@@ -157,11 +155,11 @@ class GoogleNestSubscriber:
             await asyncio.sleep(self._watchdog_delay)
 
     def wait(self):
-        """Blocks on the subscriber."""
+        """Block on the subscriber."""
         self._subscriber_future.result()
 
     def stop_async(self):
-        """Tells the subscriber to start shutting down."""
+        """Tell the subscriber to start shutting down."""
         if self._device_manager_task:
             self._device_manager_task.cancel()
         if self._watchdog_task:
@@ -171,10 +169,14 @@ class GoogleNestSubscriber:
 
     async def async_get_device_manager(self) -> DeviceManager:
         """Return the DeviceManger with the current state of devices."""
+        if not self._device_manager_task:
+            self._device_manager_task = asyncio.create_task(
+                self._async_create_device_manager()
+            )
         return await self._device_manager_task
 
     async def _async_create_device_manager(self):
-        """Creates a DeviceManager, populated with initial state."""
+        """Create a DeviceManager, populated with initial state."""
         device_manager = DeviceManager()
         structures = await self._api.async_get_structures()
         for structure in structures:
@@ -186,21 +188,17 @@ class GoogleNestSubscriber:
         return device_manager
 
     def _done_callback(self, future):
-        """Invoked when the subscriber is completed."""
+        """Teardown subscriber."""
         if future.exception():
             ex = future.exception()
             if self._healthy:
                 self._healthy = False
-                _LOGGER.warning(
-                    "Subscriber disconnected, will restart: %s: %s", type(ex), ex
-                )
-            else:
-                _LOGGER.debug("Subscriber failure: %s: %s", type(ex), ex)
+            _LOGGER.debug("Subscriber disconnected, will restart: %s: %s", type(ex), ex)
 
     async def _async_message_callback(
         self, message: pubsub_v1.subscriber.message.Message
     ):
-        """Invoked when a message is received."""
+        """Handle a received message."""
         payload = json.loads(bytes.decode(message.data))
         event = EventMessage(payload, self._auth)
         # Only accept device events once the Device Manager has been loaded.
