@@ -1,3 +1,5 @@
+"""Base library for all traits."""
+
 import aiohttp
 
 from .auth import AbstractAuth
@@ -12,10 +14,12 @@ class Command:
     """Base class for executing commands."""
 
     def __init__(self, device_id: str, auth: AbstractAuth):
+        """Initialize Command."""
         self._device_id = device_id
         self._auth = auth
 
     async def execute(self, data: dict) -> aiohttp.ClientResponse:
+        """Run the command."""
         resp = await self._auth.request(
             "post", f"{self._device_id}:executeCommand", json=data
         )
@@ -33,7 +37,7 @@ def _TraitsDict(traits: dict, trait_map: dict, cmd: Command):
 
 
 def BuildTraits(traits: dict, cmd: Command, device_type=None) -> dict:
-    """Builds a trait map out of a response dict."""
+    """Build a trait map out of a response dict."""
     # There is a bug where doorbells do not return the DoorbellChime trait.  Simulate
     # that it was returned
     if device_type and device_type == "sdm.devices.types.DOORBELL":
